/*
 * World.java
 *
 * Created on September 14, 2005, 10:23 PM
 *
 * BallWorld for ENGR2510, fall 2005 at Olin, part of the CS101 project
 * (c)2005 Olin College
 */

package ballworld;

/**
 * Describes information a Ball can get about the world and actions the ball
 * can take on the world.
 *
 * @author Mike Wessler
 */
public interface World {
    /**
     * Gets the minimum visible x coordinate in the world
     * @return the smallest visible x coordinate
     */
    public double getMinX();

    /**
     * Gets the maximum visible x coordinate in the world
     * @return the largest visible x coordinate
     */
    public double getMaxX();

    /**
     * Gets the minimum visible y coordinate in the world
     * @return the smallest visible y coordinate
     */
    public double getMinY();

    /**
     * Gets the maximum visible y coordinate in the world
     * @return the largest visible y coordinate
     */
    public double getMaxY();
    
    /**
     * Gets the Ball object that is closest to the argument, not including the
     * argument itself.
     * If there is only one ball visible on the screen,
     * this method will return null
     * @param fromBall the Ball to find neighbors for
     * @return the nearest ball to the argument if there is such a ball,
     * <code>null</code> otherwise
     */
    public Ball getClosestBall(Ball fromBall);
    
    /**
     * Adds the given Ball to the world.  If the object also implements the
     * Animate interface, the ball will start animating.
     * @param aNewBall the Ball to add
     */
    public void addBall(Ball aNewBall);
    
    /**
     * Removes the given Ball from the world.
     * @param toBeRemoved the Ball to remove
     */
    public void removeBall(Ball toBeRemoved);
}
